.\" Copyright (C) 1993 David Metcalfe (david@prism.demon.co.uk)
.\"
.\" Permission is granted to make and distribute verbatim copies of this
.\" manual provided the copyright notice and this permission notice are
.\" preserved on all copies.
.\"
.\" Permission is granted to copy and distribute modified versions of this
.\" manual under the conditions for verbatim copying, provided that the
.\" entire resulting derived work is distributed under the terms of a
.\" permission notice identical to this one
.\" 
.\" Since the Linux kernel and libraries are constantly changing, this
.\" manual page may be incorrect or out-of-date.  The author(s) assume no
.\" responsibility for errors or omissions, or for damages resulting from
.\" the use of the information contained herein.  The author(s) may not
.\" have taken the same level of care in the production of this manual,
.\" which is licensed free of charge, as they might when working
.\" professionally.
.\" 
.\" Formatted or processed versions of this manual, if unaccompanied by
.\" the source, must acknowledge the copyright and authors of this work.
.\"
.\" References consulted:
.\"     Linux libc source code
.\"     Lewine's _POSIX Programmer's Guide_ (O'Reilly & Associates, 1991)
.\"     386BSD man pages
.\" Modified Sat Jul 24 18:26:16 1993 by Rik Faith (faith@cs.unc.edu)
.\" Modified Thu Apr 11 17:11:33 1996 by Andries Brouwer (aeb@cwi.nl):
.\"     Corrected type of compar routines, as suggested by
.\"     Miguel Barreiro (enano@avalon.yaix.es).  Added example.
.\" Translated 10 Feb 1998 by Vicente Pastor Gmez <VPASTORG@santandersupernet.com , vicpastor@hotmail.com>
.TH SCANDIR 3  "11 Abr 1996" "GNU" "Manual del Programador de Linux"
.SH NOMBRE
scandir, alphasort \- busca en un directorio entradas coincidentes
.SH SINOPSIS
.nf
.B #include <dirent.h>
.sp
.BI "int scandir(const char *" dir ", struct dirent ***" namelist ,
.RS
.BI "int (*" select ")(const struct dirent *),"
.BI "int (*" compar ")(const struct dirent **, const struct dirent **));
.RE
.sp
.BI "int alphasort(const struct dirent **" a ", const struct dirent **" b );
.fi
.SH DESCRIPCIN
La funcin \fBscandir()\fP rastrea el directorio \fIdir\fP, llamando
\fBselect()\fP en cada entrada de directorio. Las entradas para las que
\fBselect()\fP devuelve un valor distinto de cero se almacenan en cadenas
(strings) reservadas va \fBmalloc()\fP, ordenadas usando \fBqsort()\fP con
la funcin de comparacin \fBcompar()\fP, y puestas en la matriz \fInamelist\fP
que est reservada va \fBmalloc()\fP.
Si \fBselect\fP es NULL, se seleccionan todas las entradas.
.PP
La funcin \fBalphasort()\fP puede ser usada como funcin de comparacin para
que la funcin \fBscandir()\fP ponga las entradas de directorio en orden
alfabtico. Sus parmetros son las dos entradas de directorio, \fIa\fP y
\fIb\fP, a comparar.
.SH "VALOR REGRESADO"
La funcin \fBscandir()\fP devuelve el nmero de entradas de directorio
seleccionadas, o \-1 si hubo algn error.
.PP
La funcin \fBalphasort()\fP devuelve un entero menor que, igual a, o mayor
que cero si el primer argumento se considera respectivamente menor que, igual
a, o mayor que el segundo argumento.
.SH "ERRORES"
.TP
.B ENOMEM
Memoria insuficiente para completar la operacin.
.SH "CONFORME A"
BSD 4.3
.SH EJEMPLO
.nf
/* imprimir ficheros en el directorio actual en orden inverso */
#include <dirent.h>
main(){
    struct dirent **namelist;
    int n;

    n = scandir(".", &namelist, 0, alphasort);
    if (n < 0)
        perror("scandir");
    else
        while(n--) printf("%s\en", namelist[n]->d_name);
}
.fi
.SH "VASE TAMBIN"
.BR opendir (3),
.BR readdir (3),
.BR closedir (3),
.BR rewinddir (3),
.BR telldir (3),
.BR seekdir (3).
